#include "Arduino.h"
#include <esp_now.h>
#include <WiFi.h>

// REPLACE WITH YOUR RECEIVER MAC Address
uint8_t broadcastAddress[] = {0xF0, 0xF5, 0xBD, 0x07, 0x81, 0x7C};

// Structure example to send data
// Must match the receiver structure
typedef struct struct_message {
  int JoyX;
  int JoyY;
} struct_message;

// Create a struct_message called myData
struct_message myNowMessage;
esp_now_peer_info_t peerInfo;

int JoyPinX = A1;
int JoyPinY = A4;
// callback when data is sent
void OnDataSent(const uint8_t *mac_addr, esp_now_send_status_t status) {
  Serial.print("\r\nLast Packet Send Status:\t");
  Serial.println(status == ESP_NOW_SEND_SUCCESS ? "Delivery Success" : "Delivery Fail");
}
 
void setup() {
  // Init Serial Monitor
  Serial.begin(115200);
 
  // Set device as a Wi-Fi Station
  WiFi.mode(WIFI_STA);

  // Init ESP-NOW
  if (esp_now_init() != ESP_OK) {
    Serial.println("Error initializing ESP-NOW");
    return;
  }

  // Once ESPNow is successfully Init, we will register for Send CB to
  // get the status of Trasnmitted packet
  esp_now_register_send_cb(OnDataSent);
  
  // Register peer
  memcpy(peerInfo.peer_addr, broadcastAddress, 6);
  peerInfo.channel = 0;  
  peerInfo.encrypt = false;
  
  // Add peer        
  if (esp_now_add_peer(&peerInfo) != ESP_OK){
    Serial.println("Failed to add peer");
    return;
  }
}
 
void loop() {
  // Servo value
  myNowMessage.JoyX = map(analogRead(JoyPinX), 0, 3200, 0, 179);
  Serial.println(myNowMessage.JoyX);

  // Motor value
  myNowMessage.JoyY = map(analogRead(JoyPinY), 1700, 3329, 0, 255);
  Serial.println(myNowMessage.JoyY);
  // Send message via ESP-NOW
  esp_now_send(broadcastAddress, (uint8_t *) &myNowMessage, sizeof(myNowMessage));
 
  delay(100);
}